import re
import os


def create_nexus_hardening_acl(config_file):
    if not os.path.exists(config_file):
        raise FileNotFoundError("File not found.")
    
    # Read the configuration file
    with open(config_file, 'r') as file:
        nexus_config = file.readlines()
    
    # Filter relevant lines
    filtered_lines = [line.strip() for line in nexus_config if (
        "ip address" in line.lower() or "interface vlan" in line.lower() or re.search(r'ip (\d+\.\d+\.\d+\.\d+)', line))]

    # Initialize output
    output_lines = [
        "no ip access-list RestrictManagement",
        "ip access-list RestrictManagement",
        "999999 permit ip any any"
    ]
    
    vlan = None
    count = 1

    for line in filtered_lines:
        if "interface vlan" in line.lower():
            # Extract VLAN number
            vlan_match = re.search(r'\d+', line)
            if vlan_match:
                vlan = vlan_match.group()
                # Output the REMARK line for the VLAN
                output_lines.append(f"{vlan}0 REMARK Interface VLAN{vlan}")
                count = 1  # Reset sequence counter for the new VLAN
        if "ip address" in line.lower():
            # Extract IP address
            ip_match = re.search(r'(\d+\.\d+\.\d+\.\d+)', line)
            if ip_match:
                ip = ip_match.group()
                # Generate deny statements for the extracted IP
                output_lines.append(f"{vlan}{count} deny tcp any {ip}/32 eq 22")
                output_lines.append(f"{vlan}{count} deny udp any {ip}/32 range 161 162")
                count += 1
        elif "ip" in line.lower():
            ip_match = re.search(r'(\d+\.\d+\.\d+\.\d+)', line)
            if ip_match:
                ip = ip_match.group()
                # Generate deny statements for the extracted IP
                output_lines.append(f"{vlan}{count} deny tcp any {ip}/32 eq 22")
                output_lines.append(f"{vlan}{count} deny udp any {ip}/32 range 161 162")
                count += 1
    
    return '\n'.join(output_lines)


# Example usage (replace with your actual configuration file path)
config_file_path = '/Users/btravan/Downloads/nexus-sw07-running-config.txt'
try:
    acl_output = create_nexus_hardening_acl(config_file_path)
    print(acl_output)
except FileNotFoundError as e:
    print(str(e))
